# Name Unity

## Purpose

A simple tool to help you unity file names.

Automatically generated file names always contains date time information, like
the photos' name created by your phone or camera. But different devices might
provide different format, so it would be me orderless if you store all these
files into one position.

This tool would help you automatically rename these files to one single format.

## Functions

- Directly get date time information from file name. Example format,

  - `IMG_20010101_120000.jpg`

## Requirements

- Python >= 3.6
- Pip >= 10.0

## Install

```shell
pip install nameunity
```

## Author

Lucas <yuanzhendai@gmail.com>
